@@ -270,8 +270,10 @@ mch_suspend()
 {
 #ifdef SIGTSTP
 	settmode(0);
+	stoptermcap();
 	kill(0, SIGTSTP);		/* send ourselves a STOP signal */
 	settmode(1);
+	starttermcap();
 #else
 	OUTSTR("new shell started\n");
 	(void)call_shell(NULL, 0, TRUE);
@@ -1187,20 +1189,18 @@ RealWaitForChar(ticks)
 	return (select(1, &fdset, NULL, NULL, (ticks >= 0) ? &tv : NULL));
 #endif
 }
-/* whats up with this?, I'm not sure, -D.J. Gregor, 2/27/95 */
-#if 0
-#if !defined(__alpha) && !defined(mips) && !defined(SCO) && !defined(remove) && !defined(CONVEX)
-	const
+
+#if !defined(__alpha) && !defined(mips) && !defined(SCO) && !defined(remove) && !defined(CONVEX) && !defined(linux)
+	int 
 remove(buf)
 # if defined(linux) || defined(__STDC__) || defined(__NeXT__) || defined(M_UNIX)
-	int 
+	const
 # endif
 			char *buf;
 {
 	return unlink(buf);
 }
 #endif
-#endif
 
 /*
  * ExpandWildCard() - this code does wild-card pattern matching using the shell
